==> silktools-0.11.7.tbz: include/silk/multiqueue.h <==
/*
** Copyright (C) 2007 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _MULTIQUEUE_H
#define _MULTIQUEUE_H

#include "silk.h"

RCSIDENTVAR(rcsID_MULTIQUEUE_H, "$SiLK: multiqueue.h 8360 2007-08-09 19:53:17Z mwd $");

/*
**  multiqueue.h
**
**  Creates queue sets.
**
*/

typedef struct _mq_multi_t mq_multi_t;
typedef struct _mq_queue_t mq_queue_t;

typedef enum { MQ_NOERROR = 0,
               MQ_DISABLED,
               MQ_SHUTDOWN,
               MQ_MEMERROR,
               MQ_ILLEGAL,
} mq_err_t;

typedef enum {
    MQ_ADD    = 1,
    MQ_REMOVE = 2,
    MQ_BOTH   = 3
} mq_function_t;

mq_multi_t *mqCreateUnfair (void (*free_fn)(void *));
mq_multi_t *mqCreateFair   (void (*free_fn)(void *));
void        mqShutdown(mq_multi_t *q);
mq_err_t    mqDisable (mq_multi_t *q, mq_function_t which);
mq_err_t    mqEnable  (mq_multi_t *q, mq_function_t which);
void        mqDestroy (mq_multi_t *q);
mq_err_t    mqGet     (mq_multi_t *q, void **data);
mq_err_t    mqPushBack(mq_multi_t *q, void *data);

mq_queue_t *mqCreateQueue (mq_multi_t *q);
void        mqDestroyQueue(mq_queue_t *sq);

mq_err_t mqQueueAdd     (mq_queue_t *sq, void *data);
mq_err_t mqQueueGet     (mq_queue_t *sq, void **data);
mq_err_t mqQueuePushBack(mq_queue_t *sq, void *data);

mq_err_t mqQueueMove   (mq_multi_t *q, mq_queue_t *sq);
mq_err_t mqQueueDisable(mq_queue_t *q, mq_function_t which);
mq_err_t mqQueueEnable (mq_queue_t *q, mq_function_t which);

#endif /* _MULTIQUEUE_H */


/*
** Local variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/

==> silktools-2.3.1_1.tbz: include/silk/multiqueue.h <==
/*
** Copyright (C) 2007-2010 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _MULTIQUEUE_H
#define _MULTIQUEUE_H

#include <silk/silk.h>

RCSIDENTVAR(rcsID_MULTIQUEUE_H, "$SiLK: multiqueue.h 15441 2010-03-10 15:58:28Z mthomas $");

/*
**  multiqueue.h
**
**  Creates queue sets.
**
*/

typedef struct mq_multi_st mq_multi_t;
typedef struct mq_queue_st mq_queue_t;

typedef enum mq_err_en {
    MQ_NOERROR = 0,
    MQ_DISABLED,
    MQ_SHUTDOWN,
    MQ_MEMERROR,
    MQ_ILLEGAL
} mq_err_t;

typedef enum mq_function_en {
    MQ_ADD    = 1,
    MQ_REMOVE = 2,
    MQ_BOTH   = 3
} mq_function_t;

mq_multi_t *mqCreateUnfair (void (*free_fn)(void *));
mq_multi_t *mqCreateFair   (void (*free_fn)(void *));
void        mqShutdown(mq_multi_t *q);
mq_err_t    mqDisable (mq_multi_t *q, mq_function_t which);
mq_err_t    mqEnable  (mq_multi_t *q, mq_function_t which);
void        mqDestroy (mq_multi_t *q);
mq_err_t    mqGet     (mq_multi_t *q, void **data);
mq_err_t    mqPushBack(mq_multi_t *q, void *data);

mq_queue_t *mqCreateQueue (mq_multi_t *q);
void        mqDestroyQueue(mq_queue_t *sq);

mq_err_t mqQueueAdd     (mq_queue_t *sq, void *data);
mq_err_t mqQueueGet     (mq_queue_t *sq, void **data);
mq_err_t mqQueuePushBack(mq_queue_t *sq, void *data);

mq_err_t mqQueueMove   (mq_multi_t *q, mq_queue_t *sq);
mq_err_t mqQueueDisable(mq_queue_t *q, mq_function_t which);
mq_err_t mqQueueEnable (mq_queue_t *q, mq_function_t which);

#endif /* _MULTIQUEUE_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
